@@ -4,7 +4,13 @@
 
 function sendViaWS (url, payload, success, failure) {
   var serialized = JSON.stringify(payload);
-  ws = new WebSocket(url);
+  var ws;
+  if ( "WebSocket" in window ) {
+    ws = new WebSocket(url);
+  } else {
+    humane.log( 'Error: Your browser does not support websockets.' );
+    return;
+  }
   ws.onmessage = function (evt) {
     var data = JSON.parse(evt.data);
     console.log( data );
@@ -19,6 +25,8 @@ function sendViaWS (url, payload, success, failure) {
     } else if ( !data.success && failure) {
       failure( data );
     }
+
+    ws.close();
   };
   ws.onopen = function () {
     //console.log( "Sending ==> " + serialized );
